@@ -45,7 +45,7 @@ class _PriceStats24h(ClientMixin):
   ) -> Mapping[S, PriceStats24h]:
     """https://developers.binance.com/docs/binance-spot-api-docs/rest-api/market-data-endpoints#24hr-ticker-price-change-statistics"""
     params  = {'symbols': encode_query([symbol, *symbols]) }
-    r = await self.client.get(f'{self.base}/api/v3/ticker/24hr', params=params)
+    r = await self.client.get(f'/api/v3/ticker/24hr', params=params)
     stats = validate_response(r.text, PriceStats24hResponse).root
     ret = {}
     for s in stats:
